@@ -5,6 +5,8 @@ LinkCollection.maxheight = 0;
 LinkCollection.render_doc = function render_doc(node, uid) {
     jq('a.current-linklist-item').removeClass('current-linklist-item');
     jq(node).addClass('current-linklist-item');
+    jq('li.current').removeClass('current');
+    jq(node.parentNode).addClass('current');
 
     jq('div.prefetched-docs').each(
 	function(i){
@@ -26,9 +28,9 @@ LinkCollection.render_doc = function render_doc(node, uid) {
     doc.height(LinkCollection.maxheight);
 
     // Scroll to the top of the linkbox
-    linkbox=jq('div#slc-linkcollection-linkbox');
-    linkboxtop=linkbox.offset().top;
-    body=jq('html,body');
+    var linkbox=jq('div#slc-linkcollection-linkbox');
+    var linkboxtop=linkbox.offset().top;
+    var body=jq('html,body');
     body.scrollTop(linkboxtop);
     return false;
 }
